/****************************************************************************
** Meta object code from reading C++ file 'volumeobject.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/plasma-pa-5.8.8/src/volumeobject.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'volumeobject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QPulseAudio__VolumeObject_t {
    QByteArrayData data[17];
    char stringdata0[234];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QPulseAudio__VolumeObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QPulseAudio__VolumeObject_t qt_meta_stringdata_QPulseAudio__VolumeObject = {
    {
QT_MOC_LITERAL(0, 0, 25), // "QPulseAudio::VolumeObject"
QT_MOC_LITERAL(1, 26, 13), // "volumeChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 12), // "mutedChanged"
QT_MOC_LITERAL(4, 54, 16), // "hasVolumeChanged"
QT_MOC_LITERAL(5, 71, 23), // "isVolumeWritableChanged"
QT_MOC_LITERAL(6, 95, 15), // "channelsChanged"
QT_MOC_LITERAL(7, 111, 21), // "channelVolumesChanged"
QT_MOC_LITERAL(8, 133, 16), // "setChannelVolume"
QT_MOC_LITERAL(9, 150, 7), // "channel"
QT_MOC_LITERAL(10, 158, 6), // "volume"
QT_MOC_LITERAL(11, 165, 5), // "muted"
QT_MOC_LITERAL(12, 171, 9), // "hasVolume"
QT_MOC_LITERAL(13, 181, 14), // "volumeWritable"
QT_MOC_LITERAL(14, 196, 8), // "channels"
QT_MOC_LITERAL(15, 205, 14), // "channelVolumes"
QT_MOC_LITERAL(16, 220, 13) // "QList<qint64>"

    },
    "QPulseAudio::VolumeObject\0volumeChanged\0"
    "\0mutedChanged\0hasVolumeChanged\0"
    "isVolumeWritableChanged\0channelsChanged\0"
    "channelVolumesChanged\0setChannelVolume\0"
    "channel\0volume\0muted\0hasVolume\0"
    "volumeWritable\0channels\0channelVolumes\0"
    "QList<qint64>"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QPulseAudio__VolumeObject[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       6,   60, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,
       3,    0,   50,    2, 0x06 /* Public */,
       4,    0,   51,    2, 0x06 /* Public */,
       5,    0,   52,    2, 0x06 /* Public */,
       6,    0,   53,    2, 0x06 /* Public */,
       7,    0,   54,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
       8,    2,   55,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::LongLong,    9,   10,

 // properties: name, type, flags
      10, QMetaType::LongLong, 0x00495103,
      11, QMetaType::Bool, 0x00495103,
      12, QMetaType::Bool, 0x00495001,
      13, QMetaType::Bool, 0x00495001,
      14, QMetaType::QStringList, 0x00495001,
      15, 0x80000000 | 16, 0x00495009,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,

       0        // eod
};

void QPulseAudio::VolumeObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        VolumeObject *_t = static_cast<VolumeObject *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->volumeChanged(); break;
        case 1: _t->mutedChanged(); break;
        case 2: _t->hasVolumeChanged(); break;
        case 3: _t->isVolumeWritableChanged(); break;
        case 4: _t->channelsChanged(); break;
        case 5: _t->channelVolumesChanged(); break;
        case 6: _t->setChannelVolume((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (VolumeObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VolumeObject::volumeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (VolumeObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VolumeObject::mutedChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (VolumeObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VolumeObject::hasVolumeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (VolumeObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VolumeObject::isVolumeWritableChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (VolumeObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VolumeObject::channelsChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (VolumeObject::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&VolumeObject::channelVolumesChanged)) {
                *result = 5;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<qint64> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        VolumeObject *_t = static_cast<VolumeObject *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qint64*>(_v) = _t->volume(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isMuted(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->hasVolume(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isVolumeWritable(); break;
        case 4: *reinterpret_cast< QStringList*>(_v) = _t->channels(); break;
        case 5: *reinterpret_cast< QList<qint64>*>(_v) = _t->channelVolumes(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        VolumeObject *_t = static_cast<VolumeObject *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVolume(*reinterpret_cast< qint64*>(_v)); break;
        case 1: _t->setMuted(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject QPulseAudio::VolumeObject::staticMetaObject = {
    { &PulseObject::staticMetaObject, qt_meta_stringdata_QPulseAudio__VolumeObject.data,
      qt_meta_data_QPulseAudio__VolumeObject,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *QPulseAudio::VolumeObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QPulseAudio::VolumeObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QPulseAudio__VolumeObject.stringdata0))
        return static_cast<void*>(this);
    return PulseObject::qt_metacast(_clname);
}

int QPulseAudio::VolumeObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PulseObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QPulseAudio::VolumeObject::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QPulseAudio::VolumeObject::mutedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QPulseAudio::VolumeObject::hasVolumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QPulseAudio::VolumeObject::isVolumeWritableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QPulseAudio::VolumeObject::channelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QPulseAudio::VolumeObject::channelVolumesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
