/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -c OsdServiceInterface -p osdservice /usr/src/ports/plasma-pa/plasma-pa-5.8.8-1.x86_64/src/plasma-pa-5.8.8/src/qml/dbus/osdService.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "osdservice.h"

/*
 * Implementation of interface class OsdServiceInterface
 */

OsdServiceInterface::OsdServiceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OsdServiceInterface::~OsdServiceInterface()
{
}


#include "osdservice.moc"
