/****************************************************************************
** Meta object code from reading C++ file 'device.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/plasma-pa-5.8.8/src/device.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'device.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QPulseAudio__Device_t {
    QByteArrayData data[23];
    char stringdata0[282];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QPulseAudio__Device_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QPulseAudio__Device_t qt_meta_stringdata_QPulseAudio__Device = {
    {
QT_MOC_LITERAL(0, 0, 19), // "QPulseAudio::Device"
QT_MOC_LITERAL(1, 20, 12), // "stateChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 11), // "nameChanged"
QT_MOC_LITERAL(4, 46, 18), // "descriptionChanged"
QT_MOC_LITERAL(5, 65, 16), // "cardIndexChanged"
QT_MOC_LITERAL(6, 82, 12), // "portsChanged"
QT_MOC_LITERAL(7, 95, 22), // "activePortIndexChanged"
QT_MOC_LITERAL(8, 118, 14), // "defaultChanged"
QT_MOC_LITERAL(9, 133, 5), // "state"
QT_MOC_LITERAL(10, 139, 5), // "State"
QT_MOC_LITERAL(11, 145, 4), // "name"
QT_MOC_LITERAL(12, 150, 11), // "description"
QT_MOC_LITERAL(13, 162, 9), // "cardIndex"
QT_MOC_LITERAL(14, 172, 5), // "ports"
QT_MOC_LITERAL(15, 178, 15), // "QList<QObject*>"
QT_MOC_LITERAL(16, 194, 15), // "activePortIndex"
QT_MOC_LITERAL(17, 210, 7), // "default"
QT_MOC_LITERAL(18, 218, 12), // "InvalidState"
QT_MOC_LITERAL(19, 231, 12), // "RunningState"
QT_MOC_LITERAL(20, 244, 9), // "IdleState"
QT_MOC_LITERAL(21, 254, 14), // "SuspendedState"
QT_MOC_LITERAL(22, 269, 12) // "UnknownState"

    },
    "QPulseAudio::Device\0stateChanged\0\0"
    "nameChanged\0descriptionChanged\0"
    "cardIndexChanged\0portsChanged\0"
    "activePortIndexChanged\0defaultChanged\0"
    "state\0State\0name\0description\0cardIndex\0"
    "ports\0QList<QObject*>\0activePortIndex\0"
    "default\0InvalidState\0RunningState\0"
    "IdleState\0SuspendedState\0UnknownState"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QPulseAudio__Device[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       7,   56, // properties
       1,   84, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,
       3,    0,   50,    2, 0x06 /* Public */,
       4,    0,   51,    2, 0x06 /* Public */,
       5,    0,   52,    2, 0x06 /* Public */,
       6,    0,   53,    2, 0x06 /* Public */,
       7,    0,   54,    2, 0x06 /* Public */,
       8,    0,   55,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       9, 0x80000000 | 10, 0x00495009,
      11, QMetaType::QString, 0x00495001,
      12, QMetaType::QString, 0x00495001,
      13, QMetaType::UInt, 0x00495001,
      14, 0x80000000 | 15, 0x00495009,
      16, QMetaType::UInt, 0x00495103,
      17, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,

 // enums: name, flags, count, data
      10, 0x0,    5,   88,

 // enum data: key, value
      18, uint(QPulseAudio::Device::InvalidState),
      19, uint(QPulseAudio::Device::RunningState),
      20, uint(QPulseAudio::Device::IdleState),
      21, uint(QPulseAudio::Device::SuspendedState),
      22, uint(QPulseAudio::Device::UnknownState),

       0        // eod
};

void QPulseAudio::Device::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Device *_t = static_cast<Device *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->descriptionChanged(); break;
        case 3: _t->cardIndexChanged(); break;
        case 4: _t->portsChanged(); break;
        case 5: _t->activePortIndexChanged(); break;
        case 6: _t->defaultChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Device::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Device::stateChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Device::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Device::nameChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Device::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Device::descriptionChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Device::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Device::cardIndexChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Device::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Device::portsChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Device::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Device::activePortIndexChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Device::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Device::defaultChanged)) {
                *result = 6;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QObject*> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        Device *_t = static_cast<Device *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< State*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->description(); break;
        case 3: *reinterpret_cast< quint32*>(_v) = _t->cardIndex(); break;
        case 4: *reinterpret_cast< QList<QObject*>*>(_v) = _t->ports(); break;
        case 5: *reinterpret_cast< quint32*>(_v) = _t->activePortIndex(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->isDefault(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        Device *_t = static_cast<Device *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setActivePortIndex(*reinterpret_cast< quint32*>(_v)); break;
        case 6: _t->setDefault(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject QPulseAudio::Device::staticMetaObject = {
    { &VolumeObject::staticMetaObject, qt_meta_stringdata_QPulseAudio__Device.data,
      qt_meta_data_QPulseAudio__Device,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *QPulseAudio::Device::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QPulseAudio::Device::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QPulseAudio__Device.stringdata0))
        return static_cast<void*>(this);
    return VolumeObject::qt_metacast(_clname);
}

int QPulseAudio::Device::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VolumeObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QPulseAudio::Device::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QPulseAudio::Device::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QPulseAudio::Device::descriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QPulseAudio::Device::cardIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QPulseAudio::Device::portsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QPulseAudio::Device::activePortIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QPulseAudio::Device::defaultChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
